/* globals "1.15.0" */
import Vue from 'vue';
import Vuex from 'vuex';
import marked from './utils/marked';
import highlight from './utils/highlight';
import { getFilenameByPath, getFileUrl, isExternalLink, inBrowser } from './utils';
import markedRenderer from './utils/markedRenderer';
import hooks from './hooks';
import load from './utils/load';
import prismLanguages from './utils/prismLanguages';
import { defaultCssVariables, darkCssVariables } from './utils/cssVariables';
import { INITIAL_STATE_NAME } from './utils/constants';
Vue.use(Vuex);
var initialState = inBrowser && window[INITIAL_STATE_NAME];
var store = new Vuex.Store({
  state: Object.assign({
    originalConfig: {},
    page: {
      title: null,
      headings: null,
      html: ''
    },
    env: {},
    showSidebar: false,
    fetchingFile: true
  }, initialState),
  mutations: {
    SET_CONFIG: function SET_CONFIG(state, config) {
      if (config === void 0) {
        config = {};
      }

      config.layout = config.layout || 'wide'; // TODO: remove `centerContent` in next major version

      if (config.centerContent) {
        config.layout = 'narrow';
      }

      config.theme = config.theme || 'default';
      state.originalConfig = config;
    },
    SET_PAGE: function SET_PAGE(state, page) {
      state.page = page;
    },
    TOGGLE_SIDEBAR: function TOGGLE_SIDEBAR(state, show) {
      state.showSidebar = typeof show === 'boolean' ? show : !state.showSidebar;
    },
    SET_FETCHING: function SET_FETCHING(state, fetching) {
      state.fetchingFile = fetching;
    },
    SET_ENV: function SET_ENV(state, env) {
      state.env = env;
    },
    SET_THEME: function SET_THEME(state, theme) {
      state.originalConfig.theme = theme;
    }
  },
  actions: {
    fetchFile: function fetchFile(_ref, path) {
      return new Promise(function ($return, $error) {
        var commit, getters, dispatch, page, filename, env;
        commit = _ref.commit, getters = _ref.getters, dispatch = _ref.dispatch;
        commit('TOGGLE_SIDEBAR', false);
        commit('SET_FETCHING', true);
        page = Object.assign({
          markdown: true
        }, getters.config.routes && getters.config.routes[path]);

        if (!page.content && !page.file) {
          filename = getFilenameByPath(path);
          page.file = getFileUrl(getters.config.sourcePath, filename);
          page.editLink = getters.config.editLinkBase && getFileUrl(getters.config.editLinkBase, filename);
        }

        return Promise.resolve(Promise.all([!page.content && fetch(page.file, getters.config.fetchOptions).then(function (res) {
          return res.text();
        }).then(function (res) {
          page.content = res;
        }), dispatch('fetchPrismLanguages')])).then(function ($await_1) {
          try {
            return Promise.resolve(hooks.processPromise('processMarkdown', page.content)).then(function ($await_2) {
              try {
                page.content = $await_2;
                return Promise.resolve(hooks.processPromise('processPage', page)).then(function ($await_3) {
                  try {
                    page = $await_3;
                    env = {
                      headings: [],
                      mixins: []
                    };

                    if (page.markdown) {
                      page.content = marked(page.content, {
                        renderer: markedRenderer(hooks),
                        highlight: highlight,
                        env: env
                      });
                    }

                    return Promise.resolve(hooks.processPromise('processHTML', page.content)).then(function ($await_4) {
                      try {
                        page.content = $await_4;
                        page.headings = env.headings;

                        if (!page.title) {
                          page.title = env.title;
                        }

                        commit('SET_PAGE', page);
                        commit('SET_ENV', env);
                        commit('SET_FETCHING', false);
                        return $return();
                      } catch ($boundEx) {
                        return $error($boundEx);
                      }
                    }, $error);
                  } catch ($boundEx) {
                    return $error($boundEx);
                  }
                }, $error);
              } catch ($boundEx) {
                return $error($boundEx);
              }
            }, $error);
          } catch ($boundEx) {
            return $error($boundEx);
          }
        }, $error);
      });
    },
    fetchPrismLanguages: function fetchPrismLanguages(_ref2) {
      var getters = _ref2.getters;
      var langs = getters.config.highlight;

      if (!langs || langs.length === 0) {
        return Promise.resolve();
      }

      return load(langs.reduce(function (res, lang) {
        if (prismLanguages[lang]) {
          res = res.concat(prismLanguages[lang]);
        }

        res.push(lang);
        return res;
      }, []).filter(function (lang, i, arr) {
        // Dedupe
        return arr.indexOf(lang) === i && prismLanguages.builtin.indexOf(lang) === -1;
      }).map(function (lang) {
        return "https://unpkg.com/prismjs@" + "1.15.0" + "/components/prism-" + lang + ".js";
      }), 'prism-languages');
    }
  },
  getters: {
    target: function target(_ref3) {
      var _target = _ref3.originalConfig.target;
      if (!_target) return 'docute';
      if (_target[0] === '#') return _target.slice(1);
      return _target;
    },
    languageOverrides: function languageOverrides(_ref4) {
      var originalConfig = _ref4.originalConfig;
      // `locales` is for legacy support
      var overrides = originalConfig.overrides || originalConfig.locales;
      return overrides && Object.keys(overrides).reduce(function (res, path) {
        if (overrides[path].language) {
          res[path] = overrides[path];
        }

        return res;
      }, {});
    },
    currentLocalePath: function currentLocalePath(_ref5, _ref6) {
      var route = _ref5.route;
      var languageOverrides = _ref6.languageOverrides;

      if (languageOverrides) {
        // Is it a locale?
        var _arr = Object.keys(languageOverrides);

        for (var _i = 0; _i < _arr.length; _i++) {
          var localePath = _arr[_i];

          if (localePath !== '/') {
            var RE = new RegExp("^" + localePath);

            if (RE.test(route.path)) {
              return localePath;
            }
          }
        }
      }

      return '/';
    },
    config: function config(_ref7, _ref8) {
      var originalConfig = _ref7.originalConfig;
      var currentLocalePath = _ref8.currentLocalePath,
          languageOverrides = _ref8.languageOverrides;
      return languageOverrides ? Object.assign({}, originalConfig, languageOverrides[currentLocalePath]) : originalConfig;
    },
    homePaths: function homePaths(_, _ref9) {
      var languageOverrides = _ref9.languageOverrides;
      var localePaths = languageOverrides ? Object.keys(languageOverrides) : [];
      return localePaths.concat(['/']);
    },
    sidebarLinks: function sidebarLinks(_, _ref10) {
      var sidebar = _ref10.sidebar;
      return sidebar ? sidebar.reduce(function (res, next) {
        // backward compabillity
        var children = next.children || next.links || [];
        return res.concat(children);
      }, []).filter(function (item) {
        return !isExternalLink(item.link);
      }) : [];
    },
    sidebar: function sidebar(_, _ref11) {
      var config = _ref11.config;
      var sidebar = config.sidebar || [];
      return typeof sidebar === 'function' ? sidebar(store) : sidebar;
    },
    cssVariables: function cssVariables(_, _ref12) {
      var config = _ref12.config;
      return Object.assign({}, config.theme === 'dark' ? darkCssVariables : defaultCssVariables, typeof config.cssVariables === 'function' ? config.cssVariables(config.theme) : config.cssVariables);
    }
  }
});

if (process.env.NODE_ENV === 'development' && inBrowser) {
  window.store = store;
}

export default store;